@@ -162,7 +162,7 @@ class BitFieldMember(Member):
             repr_format = self._argrepr
 
         elif isinstance(self._typ, EnumMeta):
-            repr_format = f"{self.name}={{str(self.{self.name})}}"
+            repr_format = f"{self.name}={{repr(self.{self.name}).split(':', 1)[0][1:]}}"
 
         else:
             repr_format = f"{self.name}={{self.{self.name}!r}}"
