@@ -12,6 +12,7 @@ from typing import Any, Generator, List, Optional, Tuple, Type, Union
 from .._code_injector import CodeInjector
 from .._typing import FactoryFormat
 from ..enum import EnumX
+from ..flag import FlagX
 from ..data import Data, DataMeta
 from ..transform import Transform
 
@@ -150,8 +151,8 @@ class Member(property):
         if isinstance(self._argrepr, str):
             repr_format = self._argrepr
 
-        elif isinstance(self._fmt, EnumX):
-            repr_format = f"{self.name}={{str(self.{self.name})}}"
+        elif isinstance(self._fmt, (EnumX, FlagX)):
+            repr_format = f"{self.name}={{repr(self.{self.name}).split(':', 1)[0][1:]}}"
 
         else:
             repr_format = f"{self.name}={{self.{self.name}!r}}"
