@@ -122,7 +122,7 @@ class TestConformance(Case):
 
             def __repr__(self) -> str:
                 try:
-                    return f"{type(self).__name__}(f1={self.f1!r}, f2={str(self.f2)}, f3={self.f3!r}, f4={self.f4!r})"
+                    return f"{type(self).__name__}(f1={self.f1!r}, f2={repr(self.f2).split(':')[0][1:]}, f3={self.f3!r}, f4={self.f4!r})"
                 except Exception:
                     return f"{type(self).__name__}()"
 
