@@ -29,9 +29,9 @@ class TestConformance(Case):
             | Offset | Access | Value | Bytes             | Format     |
             +--------+--------+-------+-------------------+------------+
             | 0      |        | 1     | 00 01             | register16 |
-            |  [0]   | .sp    | True  | ........ .......1 | bool       |
-            |  [1]   | .r0    | False | ........ ......0. | bool       |
-            |  [2]   | .r1    | False | ........ .....0.. | bool       |
+            |  [0]   | SP     | True  | ........ .......1 | bool       |
+            |  [1]   | R0     | False | ........ ......0. | bool       |
+            |  [2]   | R1     | False | ........ .....0.. | bool       |
             +--------+--------+-------+-------------------+------------+
             """
         ),
@@ -41,9 +41,9 @@ class TestConformance(Case):
             | Offset | Access | Value          | Bytes             | Format     |
             +--------+--------+----------------+-------------------+------------+
             | 0      |        | 1              | 00 01             | register16 |
-            |  [0]   | .sp    | True           | ........ .......1 | bool       |
-            |  [1]   | .r0    | False          | ........ ......0. | bool       |
-            |  [2]   | .r1    | False          | ........ .....0.. | bool       |
+            |  [0]   | SP     | True           | ........ .......1 | bool       |
+            |  [1]   | R0     | False          | ........ ......0. | bool       |
+            |  [2]   | R1     | False          | ........ .....0.. | bool       |
             +--------+--------+----------------+-------------------+------------+
             | 2      |        | <excess bytes> | 99                |            |
             +--------+--------+----------------+-------------------+------------+
