@@ -13,7 +13,7 @@ from plum.flag import FlagX
 from sample_flag import Register
 
 
-register16 = FlagX("register16", Register, byteorder="little", nbytes=2)
+register16 = FlagX(Register, byteorder="little", nbytes=2, name="register16")
 
 
 class TestPack:
