@@ -31,9 +31,9 @@ class TestInvalidValue(Case):
             | Offset | Access | Value | Bytes             | Format   |
             +--------+--------+-------+-------------------+----------+
             | 0      |        | 99    | 63 00             | register |
-            |  [0]   | .sp    | True  | ........ .......1 | bool     |
-            |  [1]   | .r0    | True  | ........ ......1. | bool     |
-            |  [2]   | .r1    | False | ........ .....0.. | bool     |
+            |  [0]   | SP     | True  | ........ .......1 | bool     |
+            |  [1]   | R0     | True  | ........ ......1. | bool     |
+            |  [2]   | R1     | False | ........ .....0.. | bool     |
             +--------+--------+-------+-------------------+----------+
             """
         ),
