@@ -11,7 +11,7 @@ from baseline import Baseline
 from plum.float import FloatX
 from plum.utilities import pack
 
-float32 = FloatX("float32", byteorder="big", nbytes=4)
+float32 = FloatX(name="float32", byteorder="big", nbytes=4)
 
 # FUTURE: Rounding precision constant
 # FUTURE: Clean up byte arrays
@@ -172,14 +172,19 @@ class TestFloatView:
         """Test representations."""
         expected_dump = Baseline(
             """
-                    +--------+-------------------+-------------+---------+
-                    | Offset | Value             | Bytes       | Format  |
-                    +--------+-------------------+-------------+---------+
-                    | 1      | 12.34567928314209 | 41 45 87 e7 | float32 |
-                    +--------+-------------------+-------------+---------+
-                    """
+            +--------+-------------------+-------------+---------+
+            | Offset | Value             | Bytes       | Format  |
+            +--------+-------------------+-------------+---------+
+            | 1      | 12.34567928314209 | 41 45 87 e7 | float32 |
+            +--------+-------------------+-------------+---------+
+            """
+        )
+        expected_repr = Baseline(
+            """
+            <float32 view at 0x1: 12.34567928314209>
+            """
         )
 
         assert str(float32_view) == "12.34567928314209"
-        assert repr(float32_view) == "<view at 0x1: float32(12.34567928314209)>"
+        assert repr(float32_view) == expected_repr
         assert str(float32_view.dump) == expected_dump
