@@ -219,16 +219,21 @@ class TestIntView:
         """Test representations."""
         expected_dump = Baseline(
             """
-                    +--------+-------+-------+--------+
-                    | Offset | Value | Bytes | Format |
-                    +--------+-------+-------+--------+
-                    | 2      | 10    | 0a    | uint8  |
-                    +--------+-------+-------+--------+
-                    """
+            +--------+-------+-------+--------+
+            | Offset | Value | Bytes | Format |
+            +--------+-------+-------+--------+
+            | 2      | 10    | 0a    | uint8  |
+            +--------+-------+-------+--------+
+            """
+        )
+        expected_repr = Baseline(
+            """
+            <uint8 view at 0x2: 10>
+            """
         )
 
         assert str(uint8_view) == "10"
-        assert repr(uint8_view) == "<view at 0x2: uint8(10)>"
+        assert repr(uint8_view) == expected_repr
         assert str(uint8_view.dump) == expected_dump
 
     def test_dereference(self, uint8_view):
