@@ -14,7 +14,7 @@ class TestSimpleItemMethods:
 
     """Test pack() and unpack() methods of items transform."""
 
-    items_x = ItemsX("items_x", fmt=None)
+    items_x = ItemsX(name="items_x", fmt=None)
 
     value = bytes(range(20))
 
@@ -89,7 +89,7 @@ class TestSimpleUtilityFunctions:
 
 class TestComplex:
 
-    items_x = ItemsX("items_x", fmt=(uint8, None))
+    items_x = ItemsX(name="items_x", fmt=(uint8, None))
 
     bindata = bytes(range(20))
     value = 0, bindata[1:]
