@@ -229,7 +229,7 @@ class TestFirst(Case):
 
             def __repr__(self) -> str:
                 try:
-                    return f"{type(self).__name__}(m1={str(self.m1)}, m2={self.m2!r}, m3={self.m3!r}, m4={self.m4!r})"
+                    return f"{type(self).__name__}(m1={repr(self.m1).split(':', 1)[0][1:]}, m2={self.m2!r}, m3={self.m3!r}, m4={self.m4!r})"
                 except Exception:
                     return f"{type(self).__name__}()"
 
