@@ -453,7 +453,7 @@ class TestTypeFactorySingleDim(Case):
 
             def __repr__(self) -> str:
                 try:
-                    return f"{type(self).__name__}(data_type={str(self.data_type)}, data_len={self.data_len!r}, data={self.data!r}, bookend={self.bookend!r})"
+                    return f"{type(self).__name__}(data_type={repr(self.data_type).split(':', 1)[0][1:]}, data_len={self.data_len!r}, data={self.data!r}, bookend={self.bookend!r})"
                 except Exception:
                     return f"{type(self).__name__}()"
 
@@ -706,7 +706,7 @@ class TestTypeFactoryMultiDim(Case):
 
             def __repr__(self) -> str:
                 try:
-                    return f"{type(self).__name__}(data_type={str(self.data_type)}, data_dims={self.data_dims!r}, data={self.data!r}, bookend={self.bookend!r})"
+                    return f"{type(self).__name__}(data_type={repr(self.data_type).split(':', 1)[0][1:]}, data_dims={self.data_dims!r}, data={self.data!r}, bookend={self.bookend!r})"
                 except Exception:
                     return f"{type(self).__name__}()"
 
@@ -836,11 +836,18 @@ class TestSetter:
         assert struct.array == [99]
 
     def test_readonly(self):
-        expected_message = Baseline(
-            """
-            can't set attribute 'array'
-            """
-        )
+        if sys.version_info < (3, 11):
+            expected_message = Baseline(
+                """
+                can't set attribute 'array'
+                """
+            )
+        else:
+            expected_message = Baseline(
+                """
+                property 'array' of 'TestSetter.test_readonly.<locals>.Struct' object has no setter
+                """
+            )
 
         class Struct(Structure):
             dims = member(fmt=uint8, compute=True)
