@@ -33,7 +33,7 @@ class TestKeyword:
     """Test explicitly defined with keyword argument."""
 
     class Struct(Structure, byteorder="big"):
-        m0 = member(fmt=ArrayX("array", fmt=uint8))
+        m0 = member(fmt=ArrayX(name="array", fmt=uint8))
 
     def test_byteorder(self):
         assert self.Struct.byteorder == "big"
