@@ -82,7 +82,7 @@ class TestVanilla(Base):
         """
         def __repr__(self) -> str:
             try:
-                return f"{type(self).__name__}(m0={self.m0!r}, m1={str(self.m1)}, m2={self.m2!r}, m3={str(self.m3)})"
+                return f"{type(self).__name__}(m0={self.m0!r}, m1={repr(self.m1).split(':', 1)[0][1:]}, m2={self.m2!r}, m3={repr(self.m3).split(':', 1)[0][1:]})"
             except Exception:
                 return f"{type(self).__name__}()"
 
