@@ -928,11 +928,18 @@ class TestComputeNoSetter:
     """Test where size member is computed but sized member is r/o or explict setter."""
 
     def test_readonly(self):
-        expected_message = Baseline(
-            """
-            can't set attribute 'string'
-            """
-        )
+        if sys.version_info < (3, 11):
+            expected_message = Baseline(
+                """
+                can't set attribute 'string'
+                """
+            )
+        else:
+            expected_message = Baseline(
+                """
+                property 'string' of 'TestComputeNoSetter.test_readonly.<locals>.Struct' object has no setter
+                """
+            )
 
         class Struct(Structure):
             size: int = member(fmt=uint8, compute=True)
