@@ -9,7 +9,7 @@ from baseline import Baseline
 from plum.conformance import wrap_message
 from plum.none import NoneX
 
-nil = NoneX("nil")
+nil = NoneX(name="nil")
 
 
 class TestExceptions:
@@ -21,6 +21,6 @@ class TestExceptions:
         with pytest.raises(TypeError) as trap:
             nil.view(buffer=bytearray())
 
-        expected = Baseline("""'nil' does not support view()""")
+        expected = Baseline("""<transform 'nil'> does not support view()""")
 
         assert wrap_message(trap.value) == expected
